==> haskell-hspec-megaparsec-2.2.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-Lk5I9yyGUdiDi6UD757y5E
key:                  hspec-megaparsec-2.2.1-Lk5I9yyGUdiDi6UD757y5E
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  4fe255f870d10568931ac7f9913de8fb
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-Lk5I9yyGUdiDi6UD757y5E
depends:
    base-4.16.4.0 hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    megaparsec-9.6.0-DyV5H5Pce9o2BVjOIdAcZh

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.2.1-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-Ax0EaTlRz081y4nJ1hAePh
key:                  hspec-megaparsec-2.2.1-Ax0EaTlRz081y4nJ1hAePh
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  8c17ad4fce13742ec0ded2997c36111e
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-Ax0EaTlRz081y4nJ1hAePh
depends:
    base-4.16.4.0 hspec-expectations-0.8.3-1zJ9Bt2UKIO1izJ8suxZW5
    megaparsec-9.6.1-2AZCVC4kdAf53IzruPN0BJ

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
